macro_rules! canic_bundle_shared_runtime_endpoints {
() => { ... };
}Expand description
Emit the default shared runtime endpoint surface for all Canic canisters.
macro_rules! canic_bundle_shared_runtime_endpoints {
() => { ... };
}Emit the default shared runtime endpoint surface for all Canic canisters.