pub struct RegisteredDiagnosticCode(/* private fields */);Expand description
RegisteredDiagnosticCode
Centrally allocated producer identity. Only the canonical declaration tree can construct this type from a number.
Implementations
Sourceimpl RegisteredDiagnosticCode
impl RegisteredDiagnosticCode
Sourcepub const fn raw_code(self) -> DiagnosticCode
pub const fn raw_code(self) -> DiagnosticCode
Return this registered producer identity as its lossless raw value.